API Reference
=============

.. automodule:: scitex_app
   :members:
   :undoc-members:

SDK Module
----------

.. automodule:: scitex_app.sdk
   :members:
   :undoc-members:

FilesBackend Protocol
---------------------

.. autoclass:: scitex_app.sdk._protocol.FilesBackend
   :members:
   :undoc-members:

FileSystemBackend
-----------------

.. autoclass:: scitex_app.sdk._filesystem.FileSystemBackend
   :members:
   :undoc-members:
